*********************************
*Garritzmann, Julian L., Busemeyer, Marius R., Neimanns, Erik (2018) Public Demand for Social Investment: New Supporting Coalitions for Welfare State Reform in Western Europe? Published in: Journal of European Public Policy.
*Stata do file for the analysis of the Inveduc data
*********************************

*Load data set
use "/[...]/Inveduc_Final-4.dta"

*use sampling weights
svyset [pweight=GEW_ALL]

*country (string variable)
gen country="DE" if COUNTRYCODE==13
replace country="DK" if COUNTRYCODE==31
replace country="ES" if COUNTRYCODE==16
replace country="FR" if COUNTRYCODE==51
replace country="IE" if COUNTRYCODE==35
replace country="IT" if COUNTRYCODE==15
replace country="SE" if COUNTRYCODE==18
replace country="UK" if COUNTRYCODE==25

*countryno (alphabetical: 1-8)
gen countryno=COUNTRYCODE
recode countryno (31=1)(51=2)(13=3)(35=4)(15=5)(16=6)(18=7)(25=8)
label define countryno 1"Denmark"2"France"3"Germany"4"Ireland"5"Italy"6"Spain"7"Sweden"8"United Kingdom", replace
label values countryno countryno

*generate common education level variable
gen educlevel=.
replace educlevel=Q641 if COUNTRYCODE==13 /*Germany*/
replace educlevel=Q642 if COUNTRYCODE==31 /*Denmark*/
replace educlevel=Q643 if COUNTRYCODE==25 /*UK*/
replace educlevel=Q644 if COUNTRYCODE==15 /*Italy*/
replace educlevel=Q645 if COUNTRYCODE==18 /*Sweden*/
replace educlevel=Q646 if COUNTRYCODE==35 /*Ireland*/
replace educlevel=Q647 if COUNTRYCODE==16 /*Spain*/
replace educlevel=Q648 if COUNTRYCODE==51 /*France*/
replace educlevel=. if educlevel>6

*categorical coding of educational degree: dummy coding
forvalues k=1/5 {
gen educlevel`k'=0 if educlevel!=.
replace educlevel`k'=1 if educlevel==`k'
}
*

*individual net income, converted by 2013 PPP rates (actual individual consumption), source: OECD Annual National Accounts, oecd.stat
recode Q75 999999=.
gen indincome=.

replace indincome=Q75/0.774431 if COUNTRYCODE==13 /*Germany*/
replace indincome=Q75/8.223798 if COUNTRYCODE==31 /*Denmark*/
replace indincome=Q75/0.733935 if COUNTRYCODE==25 /*UK*/
replace indincome=Q75/0.785934 if COUNTRYCODE==15 /*Italy*/
replace indincome=Q75/9.101086 if COUNTRYCODE==18 /*Sweden*/
replace indincome=Q75/0.923607 if COUNTRYCODE==35 /*Ireland*/
replace indincome=Q75/0.715725 if COUNTRYCODE==16 /*Spain*/
replace indincome=Q75/0.842509 if COUNTRYCODE==51 /*France*/

*log indinvidual income
gen indincome_log=ln(indincome+1)
egen indincome_log_std=std(indincome_log)
label var indincome_log_std "Individual income"

*household income (quintiles)
recode Q74 8=. 9=.
rename Q74 hhincome

*categorical household income: dummy coding
forvalues k=1/5 {
gen hhincome`k'=0 if hhincome!=.
replace hhincome`k'=1 if hhincome==`k'
label var hhincome`k' "Income (Q`k')"
}
*

*age
recode Q11 9999=.
gen age=2014-Q11

*gender
gen female=.
replace female=1 if Q12==2
replace female=0 if Q12==1

*how many children
recode Q78 9=.
gen nrkids=Q78
replace nrkids=0 if Q77==1

*kids dummy
gen kids_dummy=.
replace kids_dummy=1 if nrkids>0 & nrkids<.
replace kids_dummy=0 if nrkids==0

*how many young children
recode Q79 9=.
gen nrsmallkids=Q79
replace nrsmallkids=0 if Q78==0
replace nrsmallkids=0 if Q77==1

*small kids dummy
gen smallkids_dummy=.
replace smallkids_dummy=1 if nrsmallkids>=1
replace smallkids_dummy=0 if nrsmallkids==0
replace smallkids_dummy=. if nrsmallkids==.


*respondent´s current situation
gen currentsit=Q6602
recode currentsit (.=6) (98=.) (99=.)
replace currentsit=7 if Q6602==6 & Q6601>=2 & Q6601<=3
replace currentsit=8 if Q67>=2 & Q67<=4
label values currentsit Q6602
label define Q6602 6 "working full time" 7 "work. part-time, volunt." 8 "work. part-time, involunt.", modify

*respondent´s current situation: alternative coding: less fine-grained categories
gen currentsitv3=currentsit
recode currentsitv3 (4=96)(5=96)(7=96)(8=96)
label values currentsitv3 Q6602
*current situation: separate dummies
gen currentsitv3_1_ue=currentsitv3
gen currentsitv3_2_stud=currentsitv3
gen currentsitv3_3_ret=currentsitv3
gen currentsitv3_6_work=currentsitv3
gen currentsitv3_9_oth=currentsitv3
recode currentsitv3_1_ue (1=1)(2=0)(3=0)(6=0)(96=0) 
recode currentsitv3_2_stud (1=0)(2=1)(3=0)(6=0)(96=0)  
recode currentsitv3_3_ret (1=0)(2=0)(3=1)(6=0)(96=0)  
recode currentsitv3_6_work (1=0)(2=0)(3=0)(6=1)(96=0)  
recode currentsitv3_9_oth (1=0)(2=0)(3=0)(6=0)(96=1)  
label var currentsitv3_1_ue "unempl."
label var currentsitv3_2_stud "student"
label var currentsitv3_3_ret "Retired"
label var currentsitv3_6_work "working"
label var currentsitv3_9_oth "other"

*generate categorical age groups: for those above 60, distinguish by retirement status
gen age20s=0  
replace age20s=1 if  age <30
gen age30s=0
replace age30s=1 if  age >=30 & age <40
gen age40s=0
replace age40s=1 if  age >=40 & age <50
gen age50s=0
replace age50s=1 if  age >=50 & age <60
gen age60s=0
replace age60s=1 if  (age >=60 & age <.) & currentsitv3_3_ret!=1
gen age60s_ret=0
replace age60s_ret=1 if  (age >=60 & age <.) & currentsitv3_3_ret==1
*alternative coding: not distinguishing by retirement status for those above 60
gen age60s_all=0
replace age60s_all=1 if  (age >=60 & age <.)


*********************************
*correcting Osch-16 social class scheme: consider only dependent employees (Q68==2 & Q68==3)
*note: not possible to code self-employed into the class scheme because of lack of information on the number of employees
*Osch-16 social class scheme: 1 "Large employers"	2 "Self-employed professionals"	3 "Small business owners with employees"	4 "Small business owners without employees"	5 "Technical experts"	6 "Technicians"	7 "Skilled manual"	8 "Low-skilled manual"	9 "Higher-grade managers and administrators"	10 "Lower-grade managers and administrators"	11 "Skilled clerks"	12 "Unskilled clerks"	13 "Socio-cultural professionals"	14 "Socio-cultural semi-professionals"	15 "Skilled service"	16 "Low-skilled service"
replace oesch16=. if (Q68==1 | Q68==4| Q68==6| Q68==9)

*Schwander/Häusermann 2013 class scheme:
*based on Oesch 2006, Kitschelt/Rehm 2005, Häusermann 2010
*1: Capital accumulators, 2: Socio-cultural professionals, 3: Blue collar workers, 4: Low service functionaries, 5: Mixed service functionaries, 6:n.a.
*class:
gen class=oesch16
recode class (5=1)(6=5)(7=3)(8=3)(9=1)(10=1)(11=5)(12=5)(13=2)(14=2)(15=4)(16=4)
recode class (.=6) 
label define class 1 "CA" 2 "SCP" 3 "BC" 4 "LSF" 5 "MSF" 6"n.a."
label values class class
*code self-employed (Q68==1 | Q68==4) as separate category:
replace class=7 if (Q68==1 | Q68==4)
*code retired as separate category of class (note: only respondents in employment were asked for their occupation)
replace class=8 if currentsitv3_3_ret==1
label define class 1 "CA" 2 "SCP" 3 "BC" 4 "LSF" 5 "MSF" 6"n.a." 7"self-emp" 8"retired", replace
label values class class
*dummy coding:
forvalues k=1/8 {
gen class`k'=class 
replace class`k'=1 if class==`k'
replace class`k'=0 if class!=`k'
}
label variable class1 "Capital accumulators" 
label variable class2 "Socio-cultural professionals" 
label variable class3 "Blue-collar" 
label variable class4 "Low service functionaries" 
label variable class5 "Mixed service functionaries" 
label variable class6 "Class: n.a." 
label variable class7 "Self-employed" 
label variable class8 "Retired"
*


*********************************
*Coding of preference variables
*********************************

***Recode missings
recode  Q23_* Q26_* Q27  (8=.) (9=.)
recode Q25 (98=.) (99=.)

*Recode variables: higher values indicate preferences for more spending ...
foreach var of varlist  Q23_1-Q23_9 Q26_1-Q26_4  { 
gen `var'_rec = `var'
recode `var'_rec (5=1)(4=2)(2=4)(1=5)
} 
label define spending_inv 1"spend much less"2"spend less"3"spend the same as now"4"spend more"5"spend much more"
label values  Q23_1_rec Q23_2_rec Q23_3_rec Q23_4_rec Q23_5_rec Q23_6_rec Q23_7_rec Q23_8_rec Q23_9_rec Q26_1_rec Q26_2_rec Q26_3_rec Q26_4_rec spending_inv

foreach var of varlist Q14_1 Q14_2 Q14_3 Q14_4 Q14_5 Q18_1 Q18_2 Q18_3 Q18_4 Q18_5 Q18_6 {
recode `var' (8 9=.)
gen `var'rec=`var' 
recode `var'rec (1=5)(2=4)(3=3)(4=2)(5=1)
}
*


*Recoding of policy reform items (Q18)

gen si1=.
replace si1=1 if Q18_2==1 | Q18_2==2
replace si1=0 if Q18_2==3 | Q18_2==4 | Q18_2==5

gen si2=.
replace si2=1 if Q18_3==1 | Q18_3==2
replace si2=0 if Q18_3==3 | Q18_3==4 | Q18_3==5

gen si3=.
replace si3=1 if Q18_5==1 | Q18_5==2
replace si3=0 if Q18_5==3 | Q18_5==4 | Q18_5==5

gen pa1=.
replace pa1=1 if Q18_1==1 | Q18_1==2
replace pa1=0 if Q18_1==3 | Q18_1==4 | Q18_1==5

gen pa2=.
replace pa2=1 if Q18_4==1 | Q18_4==2
replace pa2=0 if Q18_4==3 | Q18_4==4 | Q18_4==5

gen pa3=.
replace pa3=1 if Q18_6==1 | Q18_6==2
replace pa3=0 if Q18_6==3 | Q18_6==4 | Q18_6==5

*relative support for social investment (si1, si2, si3) and passive transfers (pa2, pa3)
gen si=(si1+si2+si3)/3
gen pa_narrow=(pa2+pa3)/2


*Variable labelling
label var si "Social investment"
label var pa_narrow "Passive social transfers"
label var pa1 "Workfare"
label var COUNTRYCODE "country"
label var countryno "country"
label var educlevel1 "Lower sec. educ."
label var educlevel2 "Upper sec. (general)"
label var educlevel3 "Upper sec. (vocational)"
label var educlevel4 "Post-sec., non higher educ."
label var educlevel5 "Higher education"
label var age20s "Age below 30"
label var age30s "Age 30s"
label var age40s "Age 40s"
label var age50s "Age 50s"
label var age60s "Age 60+ (not retired)"
label var age60s_ret "Age 60+ (retired)"
label var age60s_all "Age 60+"
label var hhincome "Income"
label var educlevel "Education"
label var female "Gender (Female)"
label var smallkids_dummy "Small kids at home" 


*********************************
*Empirical analysis
*********************************

*Principal component factor analysis: economic left-right and social values (Table A.7)
factor Q14_1rec Q14_2rec Q14_3rec Q14_4rec Q14_5rec, pcf
rotate
predict galtan econlr
replace econlr=econlr*-1
label var galtan "Social values (right)"
label var econlr "Economic left-right (right)"


*Principal component factor analysis: six policy reform proposals (Table 1)
factor Q18_1rec Q18_2rec Q18_3rec Q18_4rec Q18_5rec Q18_6rec, pcf
rotate
predict socinv pasp workf
label var socinv "Social investment"
label var pasp "Passive transfers"
label var workf "Workfare"

*Robustness: using a polychoric correlation matrix as input for the principal component factor analysis to account for the ordinal character of the variables:
/*
polychoric Q18_1rec Q18_2rec Q18_3rec Q18_4rec Q18_5rec Q18_6rec
display r(sum_w)
global N = r(sum_w)
matrix r = r(R)
factormat r, n($N) pcf
rotate
predict socinv pasp workf
label var socinv "Social investment"
label var pasp "Passive social transfers"
label var workf "Workfare"
*/


*Figure 1:
graph bar (mean) si pa_narrow pa1 [pweight=GEW_ALL], blabel(bar, format(%4.2g)) by(countryno, total) legend(rows(1) order(1 "Social investment" 2 "Passive social transfers" 3 "Workfare")) scheme(s2mono)



******************************************************************************************************
*Figure 2 (and Table A.4, Models 1-3): 
******************************************************************************************************
set more off
reg socinv educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m1
reg pasp educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m2
reg workf educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE , vce (cluster COUNTRYCODE)
est store m3

coefplot m1,bylabel(Social Investment) || m2,bylabel(Passive transfers) || m3,bylabel(Workfare) ||, keep (educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr) xline(0) byopts(row(1)) ///
 coeflabel(educlevel="Education" hhincome="Income"  female="Female" smallkids_dummy="Small kids" age20s="Age 18-29" age40s="Age 40-49" age50s="Age 50-59" age60s="60+ (not retired)" age60s_ret="60+ (retired)" galtan="Soc. values right" econlr="Economic right") ///
 plotlabels("SocialInvestment""Passivesocialtransfers""Workfare") xlabel(-.3(.1).3) name(coefplot_f2, replace) 



***
*Additional analysis included in the Supplementary Material
***

*Figure A.1 (and Table A.4, Models 4-6)
set more off
logit si1 educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
margins, dydx(*) post
est store m4
logit si2 educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
margins, dydx(*) post
est store m5
logit si3 educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
margins, dydx(*) post
est store m6

coefplot m4,bylabel(Labor Market Training) || m5,bylabel(Expand childcare) || m6,bylabel(Unis and research) ||, keep (educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr) xline(0) byopts(row(1)) ///
 coeflabel(educlevel="Education" hhincome="Income"  female="Female" smallkids_dummy="Small kids" age20s="Age 18-29" age40s="Age 40-49" age50s="Age 50-59" age60s="60+ (not retired)" age60s_ret="60+ (retired)" galtan="Soc. values right" econlr="Economic right") ///
 xlabel(-.2(.1).2) name(coefplot_fa1, replace) 

*Figure A.2 (and Table A.4, Models 7-9)
set more off
logit pa1 educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
margins, dydx(*) post
est store m7
logit pa2 educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
margins, dydx(*) post
est store m8
logit pa3 educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
margins, dydx(*) post
est store m9

coefplot m7,bylabel(Workfare) || m8,bylabel(Pension increase) || m9,bylabel(Early retirement) ||, keep (educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr) xline(0) byopts(row(1)) ///
 coeflabel(educlevel="Education" hhincome="Income"  female="Female" smallkids_dummy="Small kids" age20s="Age 18-29" age40s="Age 40-49" age50s="Age 50-59" age60s="60+ (not retired)" age60s_ret="60+ (retired)" galtan="Soc. values right" econlr="Economic right") ///
 xlabel(-.2(.1).2) name(coefplot_fa2, replace) 


*Table A.2: Summary statistics
sum Q18_2rec Q18_3rec Q18_5rec Q18_1rec Q18_4rec Q18_6rec educlevel hhincome female smallkids_dummy age galtan econlr class indincome_log_std ///
 if !missing(Q18_1rec, Q18_2rec, Q18_3rec, Q18_4rec, Q18_5rec, Q18_6rec, educlevel, hhincome, female, smallkids_dummy, age20s, age40s, age50s, age60s, age60s_ret, galtan, econlr)


*Table A.3: (Rotated) Principal component factor analyses by country
*DK:
factor Q18_1rec Q18_2rec Q18_3rec Q18_4rec Q18_5rec Q18_6rec if countryno==1, pcf 
rotate
*FR:
factor Q18_1rec Q18_2rec Q18_3rec Q18_4rec Q18_5rec Q18_6rec if countryno==2, pcf 
rotate
*DE:
factor Q18_1rec Q18_2rec Q18_3rec Q18_4rec Q18_5rec Q18_6rec if countryno==3, pcf 
rotate
*IE:
factor Q18_1rec Q18_2rec Q18_3rec Q18_4rec Q18_5rec Q18_6rec if countryno==4, pcf 
rotate
*IT:
factor Q18_1rec Q18_2rec Q18_3rec Q18_4rec Q18_5rec Q18_6rec if countryno==5, pcf 
rotate
*ES:
factor Q18_1rec Q18_2rec Q18_3rec Q18_4rec Q18_5rec Q18_6rec if countryno==6, pcf 
rotate
*SE:
factor Q18_1rec Q18_2rec Q18_3rec Q18_4rec Q18_5rec Q18_6rec if countryno==7, pcf 
rotate
*UK:
factor Q18_1rec Q18_2rec Q18_3rec Q18_4rec Q18_5rec Q18_6rec if countryno==8, pcf 
rotate


************************************************
*Table A.4 (continued): Robustness analyses
************************************************
*Models 10-12: Ideological variables (galtan, econlr) dropped  
set more off
reg socinv educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret   i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m1
reg pasp educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret   i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m2
reg workf educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret   i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m3
coefplot m1,bylabel(Social Investment) || m2,bylabel(Passive transfers) || m3,bylabel(Workfare) ||, keep (educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret  ) xline(0) byopts(row(1)) ///
 coeflabel(educlevel="Education" hhincome="Income"  female="Female" smallkids_dummy="Small kids" age20s="Age < 30" age60s="60+ (not ret.)" age60s_ret="60+ (ret.)" ) ///
 plotlabels("SocialInvestment""Passivesocialtransfers""Workfare") xlabel(-.3(.1).3) name(coefplot_f2r1, replace) 

*Models 13-15: Occupational class instead of income and education (need to use age60s_all instead of age60s age60s_ret)
set more off
reg socinv  class1 class2 class4 class5 class6 class7 class8   female smallkids_dummy age20s age40s age50s age60s_all  galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m1
reg pasp  class1 class2 class4 class5 class6 class7 class8 female smallkids_dummy age20s age40s age50s age60s_all  galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m2
reg workf  class1 class2 class4 class5 class6 class7 class8 female smallkids_dummy age20s age40s age50s age60s_all  galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m3
coefplot m1,bylabel(Social Investment) || m2,bylabel(Passive transfers) || m3,bylabel(Workfare) ||, keep (class1 class2 class4 class5  class7 class8   female smallkids_dummy age20s age40s age50s age60s_all  galtan econlr) xline(0) byopts(row(1)) ///
 coeflabel(  female="Female" smallkids_dummy="Small kids" age20s="Age < 30" age60s="60+ (not ret.)" age60s_ret="60+ (ret.)" galtan="Values right" econlr="Econ. right") ///
 plotlabels("SocialInvestment""Passivesocialtransfers""Workfare") xlabel(-.3(.1).3) name(coefplot_f2r2, replace) 

*Models 16-18: Occupational class in addition to education and income (need to use age60s_all instead of age60s age60s_ret)
set more off
reg socinv educlevel hhincome class1 class2 class4 class5 class6 class7 class8 female smallkids_dummy age20s age40s age50s age60s_all galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m1
reg pasp educlevel hhincome class1 class2 class4 class5 class6 class7 class8 female smallkids_dummy age20s age40s age50s age60s_all galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m2
reg workf educlevel hhincome class1 class2 class4 class5 class6 class7 class8 female smallkids_dummy age20s age40s age50s age60s_all galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m3
coefplot m1,bylabel(Social Investment) || m2,bylabel(Passive transfers) || m3,bylabel(Workfare) ||, keep (educlevel hhincome class1 class2 class4 class5  class7 class8 female smallkids_dummy age20s age40s age50s age60s_all galtan econlr) xline(0) byopts(row(1)) ///
 coeflabel(educlevel="Education" hhincome="Income"  female="Female" smallkids_dummy="Small kids" age20s="Age < 30" age60s="60+ (not ret.)" age60s_ret="60+ (ret.)" galtan="Values right" econlr="Econ. right") ///
 plotlabels("SocialInvestment""Passivesocialtransfers""Workfare") xlabel(-.3(.1).3) name(coefplot_f2r3, replace) 

*Models 19-21: Categorical household income
set more off
reg socinv educlevel hhincome2 hhincome3 hhincome4 hhincome5   female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m1
reg pasp educlevel hhincome2 hhincome3 hhincome4 hhincome5 female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m2
reg workf educlevel hhincome2 hhincome3 hhincome4 hhincome5 female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m3
coefplot m1,bylabel(Social Investment) || m2,bylabel(Passive transfers) || m3,bylabel(Workfare) ||, keep (educlevel hhincome2 hhincome3 hhincome4 hhincome5 female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr) xline(0) byopts(row(1)) ///
 coeflabel(educlevel="Education" hhincome="Income"  female="Female" smallkids_dummy="Small kids" age20s="Age < 30" age60s="60+ (not ret.)" age60s_ret="60+ (ret.)" galtan="Values right" econlr="Econ. right") ///
 plotlabels("SocialInvestment""Passivesocialtransfers""Workfare") xlabel(-.3(.1).3) name(coefplot_f2r4, replace) 

*Models 22-24: Individual income (indincome_log)
set more off
reg socinv educlevel indincome_log_std female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m1
reg pasp educlevel indincome_log_std female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m2
reg workf educlevel indincome_log_std female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m3
coefplot m1,bylabel(Social Investment) || m2,bylabel(Passive transfers) || m3,bylabel(Workfare) ||, keep (educlevel indincome_log_std female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr) xline(0) byopts(row(1)) ///
 coeflabel(educlevel="Education" hhincome="Income"  female="Female" smallkids_dummy="Small kids" age20s="Age < 30" age60s="60+ (not ret.)" age60s_ret="60+ (ret.)" galtan="Values right" econlr="Econ. right") ///
 plotlabels("SocialInvestment""Passivesocialtransfers""Workfare") xlabel(-.3(.1).3) name(coefplot_f2r5, replace) 

*Models 25-27: Categorical educational degrees
set more off
reg socinv educlevel1 educlevel2 educlevel3 educlevel4 hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m1
reg pasp educlevel1 educlevel2 educlevel3 educlevel4 hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m2
reg workf educlevel1 educlevel2 educlevel3 educlevel4 hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE, vce (cluster COUNTRYCODE)
est store m3
coefplot m1,bylabel(Social Investment) || m2,bylabel(Passive transfers) || m3,bylabel(Workfare) ||, keep (educlevel1 educlevel2 educlevel3 educlevel4 hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr) xline(0) byopts(row(1)) ///
 coeflabel(educlevel="Education" hhincome="Income"  female="Female" smallkids_dummy="Small kids" age20s="Age < 30" age60s="60+ (not ret.)" age60s_ret="60+ (ret.)" galtan="Values right" econlr="Econ. right") ///
 plotlabels("SocialInvestment""Passivesocialtransfers""Workfare") xlabel(-.3(.1).3) name(coefplot_f2r6, replace) 
 
 
 
******************************************************************************************************
*Table A.5: Determinants of social investment, passive transfer, and workfare policy proposals. Excluding countries with varying factor configurations (Denmark, Sweden, United Kingdom)
******************************************************************************************************
set more off
reg socinv educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE if countryno!=2 & countryno!=7 & countryno!=8, vce (cluster COUNTRYCODE) 
est store m1
reg pasp educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE if countryno!=2 & countryno!=7 & countryno!=8, vce (cluster COUNTRYCODE)
est store m2
reg workf educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr i.COUNTRYCODE  if countryno!=2 & countryno!=7 & countryno!=8, vce (cluster COUNTRYCODE)
est store m3

coefplot m1,bylabel(Social Investment) || m2,bylabel(Passive transfers) || m3,bylabel(Workfare) ||, keep (educlevel hhincome female smallkids_dummy age20s age40s age50s age60s age60s_ret galtan econlr) xline(0) byopts(row(1)) ///
 coeflabel(educlevel="Education" hhincome="Income"  female="Female" smallkids_dummy="Small kids" age20s="Age 18-29" age40s="Age 40-49" age50s="Age 50-59" age60s="60+ (not retired)" age60s_ret="60+ (retired)" galtan="Soc. values right" econlr="Economic right") ///
 plotlabels("SocialInvestment""Passivesocialtransfers""Workfare") xlabel(-.3(.1).3) name(coefplot_f2, replace) 

 
*Table A.6: Rotated factor loadings and Eigenvalues after principal-component factor analysis, spending proxies, pooled sample.
factor Q23_1_rec Q23_2_rec Q23_3_rec Q26_1_rec Q26_2_rec Q26_3_rec Q26_4_rec,pcf
rotate 

